@@ -19,7 +19,7 @@ use Socket;
 # and PF_INET6 so selectively import things from Socket6.
 use Socket6 (
     qw(AI_PASSIVE inet_ntop inet_pton getaddrinfo 
-    sockaddr_in6 unpack_sockaddr_in6_all)
+    sockaddr_in6 unpack_sockaddr_in6_all pack_sockaddr_in6_all)
 );
 
 use Carp;
@@ -27,7 +27,7 @@ use Exporter;
 use Errno;
 
 @ISA = qw(IO::Socket);
-$VERSION = "2.53";
+$VERSION = "2.55";
 #Purpose: allow protocol independent protocol and original interface.
 
 my $EINVAL = exists(&Errno::EINVAL) ? Errno::EINVAL() : 1;
@@ -173,12 +173,18 @@ sub configure {
 	    unless (scalar(@rres)>=5);
     }
 
-    while(1) {
+    LOOP_LRES: while(1) {
 
 	$family = (exists $arg->{PeerAddr})? ($rres[0]):($lres[0]) ;  # One concrete family.
 
 	#printf "DEBUG $family \n";
-	(undef,undef,undef,$lres,undef,@lres) =  @lres; 
+    my $fam_listen;
+	($fam_listen,undef,undef,$lres,undef,@lres) =  @lres;
+    
+    if ($fam_listen != $family)
+    {
+        next LOOP_LRES;
+    }
 
       	if ($lres && $family == AF_INET6) {
        	    if ($arg->{LocalFlow} || $arg->{LocalScope}) {
